@@ -1,27 +1,26 @@
 # -*- coding: utf-8 -*-
 
 '''Wrappers for various units of text.'''
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 import sys
 import json
 import string as pystring
 from collections import defaultdict
 
-from .packages import nltk
-from .decorators import cached_property
-from .utils import lowerstrip, PUNCTUATION_REGEX
-from .inflect import singularize as _singularize, pluralize as _pluralize
-from .mixins import ComparableMixin
-from .compat import (string_types, unicode, basestring,
-    python_2_unicode_compatible, u)
-from .np_extractors import BaseNPExtractor, FastNPExtractor
-from .taggers import BaseTagger, PatternTagger
-from .tokenizers import BaseTokenizer, WordTokenizer, SentenceTokenizer
-from .sentiments import BaseSentimentAnalyzer, PatternAnalyzer
-from .parsers import BaseParser, PatternParser
-from .translate import Translator
-from .en import suggest
-from .exceptions import MissingCorpusException
+from text.packages import nltk
+from text.decorators import cached_property
+from text.utils import lowerstrip, PUNCTUATION_REGEX
+from text.inflect import singularize as _singularize, pluralize as _pluralize
+from text.mixins import BlobComparableMixin
+from text.compat import unicode, basestring, python_2_unicode_compatible, u
+from text.np_extractors import BaseNPExtractor, FastNPExtractor
+from text.taggers import BaseTagger, PatternTagger
+from text.tokenizers import BaseTokenizer, WordTokenizer, SentenceTokenizer
+from text.sentiments import BaseSentimentAnalyzer, PatternAnalyzer
+from text.parsers import BaseParser, PatternParser
+from text.translate import Translator
+from text.en import suggest
+from text.exceptions import MissingCorpusException
 
 
 class Word(unicode):
@@ -222,7 +221,7 @@ def _initialize_models(obj, tokenizer, pos_tagger,
     obj.classifier = classifier
 
 @python_2_unicode_compatible
-class BaseBlob(ComparableMixin):
+class BaseBlob(BlobComparableMixin):
 
     '''An abstract base class that all text.blob classes will inherit from.
     Includes words, POS tag, NP, and word count properties. Also includes
@@ -255,7 +254,7 @@ class BaseBlob(ComparableMixin):
     def __init__(self, text, tokenizer=None,
                 pos_tagger=None, np_extractor=None, analyzer=None,
                 parser=None, classifier=None, clean_html=False):
-        if type(text) not in string_types:
+        if not isinstance(text, basestring):
             raise TypeError('The `text` argument passed to `__init__(text)` '
                             'must be a string, not {0}'.format(type(text)))
         if clean_html:
@@ -489,15 +488,6 @@ class BaseBlob(ComparableMixin):
         '''
         return self.raw
 
-    def __eq__(self, other):
-        '''Equality comparator. Blobs are be equal to blobs with the same
-        text and also to their string counterparts.
-        '''
-        if type(other) in string_types:
-            return self.raw == other
-        else:
-            return super(BaseBlob, self).__eq__(other)
-
     def __hash__(self):
         return hash(self._cmpkey())
 
@@ -519,7 +509,7 @@ class BaseBlob(ComparableMixin):
         Arguments:
         - `other`: a string or a text object
         '''
-        if type(other) in string_types:
+        if isinstance(other, basestring):
             return TextBlob(self.raw + other)
         elif isinstance(other, BaseBlob):
             return TextBlob(self.raw + other.raw)
